@@ -517,12 +517,10 @@ class Testbed:
         self.deps_installed = deps_new
         if not deps_new:
             return
-        # Test dependencies are treated as build dependencies, which in
-        # practice means that the :native architecture qualifier is supported.
+
         self.satisfy_dependencies_string(
             ', '.join(deps_new),
             'install-deps',
-            build_dep=True,
             shell_on_failure=shell_on_failure,
             synth_deps=synth_deps
         )
@@ -937,11 +935,36 @@ class Testbed:
         legacy_apt = (self.apt_version < Version('1.9.0'))
 
         if legacy_apt:
+            # Fallback to installing test dependencies via a dummy binary .deb.
+            #
+            # TODO for when we'll be able to assume apt (>= 1.1exp1) on the testbed:
+            # 1. Switch from installing deps via `dpkg --unpack autopkgtest-satdep.deb`
+            #    + `apt-get --fix-broken` + `apt-get purge autokgtest-satdep` to
+            #    `apt-get build-dep autopkgtest-satdep.dsc`.
+            #    See: b86576aa47f6f95985c3be46e4a4e20278da4511.
+            # 2. Drop the special handling of :native.
             adtlog.debug('Legacy testbed apt, installing dependencies via autopkgtest-satdep.deb')
-            # Fallback to installing test dependencies via a dummy binary .deb
-            # package. We need to strip :native qualifiers as they are not
-            # valid in d/control Depends for binary packages.
+
+            # We need to strip :native qualifiers as they are not valid in
+            # DEBIAN/control Depends, see deb-control(5), and compare with
+            # deb-src-control(5).
             deps = deps.replace(':native', '')
+
+            try:
+                deps = subprocess.run(
+                    [
+                        os.path.join(PKGDATADIR, 'lib', 'parse-deps.pl'),
+                        deps,
+                        self.dpkg_arch,
+                    ],
+                    check=True,
+                    capture_output=True,
+                    text=True,
+                ).stdout.strip()
+            except subprocess.CalledProcessError as e:
+                self.bomb(f'failed to run: {e.cmd}')
+            adtlog.debug(f"architecture resolved deps: {deps}")
+
             # generate a dummy package with the deps
             satdep_package = self._generate_satdep_deb(deps)
             satdep_package.copydown()
@@ -1083,29 +1106,11 @@ class Testbed:
                 self.run_shell()
             self.bomb("Failure installing build dependencies on testbed")
 
-    def satisfy_dependencies_string(self, deps, what,
-                                    build_dep=False, shell_on_failure=False, synth_deps=[]):
+    def satisfy_dependencies_string(self, deps, what, shell_on_failure=False, synth_deps=[]):
         '''Install dependencies from a string into the testbed'''
 
         adtlog.debug('%s: satisfying %s' % (what, deps))
 
-        try:
-            deps = subprocess.run(
-                [
-                    os.path.join(PKGDATADIR, 'lib', 'parse-deps.pl'),
-                    deps,
-                    self.dpkg_arch,
-                    'build-depends' if build_dep else 'depends',
-                ],
-                check=True,
-                capture_output=True,
-                text=True,
-            ).stdout.strip()
-        except subprocess.CalledProcessError as e:
-            self.bomb(f'failed to run: {e.cmd}')
-
-        adtlog.debug('%s: architecture resolved: %s' % (what, deps))
-
         # check if we can use apt-get
         can_apt_get = False
         if 'root-on-testbed' in self.caps:
@@ -1478,10 +1483,12 @@ Pin-Priority: $prio
         # prefer given packages from source suite, but make sure that
         # other packages are taken from default suite as much as
         # possible
-        pref_content = pref_template.substitute(
-            pkgs=pkglist.replace(',', ' '),
-            release=release,
-            prio='995')
+        pref_content = ""
+        if pkglist:
+            pref_content += pref_template.substitute(
+                pkgs=pkglist.replace(',', ' '),
+                release=release,
+                prio='995')
         for default in default_releases:
             pref_content += pref_template.substitute(
                 pkgs="*",
